Eurobot2012_Primary

Dependencies:   mbed Eurobot_2012_Primary

Revision:
15:acae5c0e9ca8
Parent:
9:377560539b74
--- a/Eurobot_shared/Kalman/Sonar/RFSRF05.cpp	Sat Apr 28 20:44:09 2012 +0000
+++ b/Eurobot_shared/Kalman/Sonar/RFSRF05.cpp	Sat Apr 28 22:21:03 2012 +0000
@@ -141,8 +141,8 @@
         ValidPulse = false;
 
         //Calucate distance
-        //true offset is about 330, we put 400 so circles overlap
-        _dist[_beacon_counter] =  _timer.read_us()/2.9 + 400;
+        //true offset is about 330, we put 450 so circles overlap
+        _dist[_beacon_counter] =  _timer.read_us()/2.9 + 450;
 
         if (callbackfunc)
             (*callbackfunc)(_beacon_counter, _dist[_beacon_counter]);